==> field_manager_python_client-4.4.82rc3.tar.gz: field_manager_python_client-4.4.82rc3/field-manager-python-client/models/plot_sequence_options.py <==
from typing import Any, Dict, Type, TypeVar, Tuple, Optional, BinaryIO, TextIO, TYPE_CHECKING

from typing import List


from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import Dict
from typing import Union

if TYPE_CHECKING:
  from ..models.pdf_options import PdfOptions





T = TypeVar("T", bound="PlotSequenceOptions")


@_attrs_define
class PlotSequenceOptions:
    """ 
        Attributes:
            auto_set_depth (Union[Unset, bool]):  Default: False.
            pdf_filename (Union[Unset, str]):  Default: 'factual_report.pdf'.
            pdf (Union[Unset, PdfOptions]):
     """

    auto_set_depth: Union[Unset, bool] = False
    pdf_filename: Union[Unset, str] = 'factual_report.pdf'
    pdf: Union[Unset, 'PdfOptions'] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        from ..models.pdf_options import PdfOptions
        auto_set_depth = self.auto_set_depth

        pdf_filename = self.pdf_filename

        pdf: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pdf, Unset):
            pdf = self.pdf.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if auto_set_depth is not UNSET:
            field_dict["auto_set_depth"] = auto_set_depth
        if pdf_filename is not UNSET:
            field_dict["pdf_filename"] = pdf_filename
        if pdf is not UNSET:
            field_dict["pdf"] = pdf

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.pdf_options import PdfOptions
        d = src_dict.copy()
        auto_set_depth = d.pop("auto_set_depth", UNSET)

        pdf_filename = d.pop("pdf_filename", UNSET)

        _pdf = d.pop("pdf", UNSET)
        pdf: Union[Unset, PdfOptions]
        if isinstance(_pdf,  Unset):
            pdf = UNSET
        else:
            pdf = PdfOptions.from_dict(_pdf)




        plot_sequence_options = cls(
            auto_set_depth=auto_set_depth,
            pdf_filename=pdf_filename,
            pdf=pdf,
        )


        plot_sequence_options.additional_properties = d
        return plot_sequence_options

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> field_manager_python_client-4.4.90rc6.tar.gz: field_manager_python_client-4.4.90rc6/field-manager-python-client/models/plot_sequence_options.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.pdf_options import PdfOptions


T = TypeVar("T", bound="PlotSequenceOptions")


@_attrs_define
class PlotSequenceOptions:
    """
    Attributes:
        auto_set_depth (Union[Unset, bool]):  Default: False.
        pdf_filename (Union[Unset, str]):  Default: 'factual_report.pdf'.
        pdf (Union[Unset, PdfOptions]):
    """

    auto_set_depth: Union[Unset, bool] = False
    pdf_filename: Union[Unset, str] = "factual_report.pdf"
    pdf: Union[Unset, "PdfOptions"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        auto_set_depth = self.auto_set_depth

        pdf_filename = self.pdf_filename

        pdf: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pdf, Unset):
            pdf = self.pdf.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if auto_set_depth is not UNSET:
            field_dict["auto_set_depth"] = auto_set_depth
        if pdf_filename is not UNSET:
            field_dict["pdf_filename"] = pdf_filename
        if pdf is not UNSET:
            field_dict["pdf"] = pdf

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.pdf_options import PdfOptions

        d = src_dict.copy()
        auto_set_depth = d.pop("auto_set_depth", UNSET)

        pdf_filename = d.pop("pdf_filename", UNSET)

        _pdf = d.pop("pdf", UNSET)
        pdf: Union[Unset, PdfOptions]
        if isinstance(_pdf, Unset):
            pdf = UNSET
        else:
            pdf = PdfOptions.from_dict(_pdf)

        plot_sequence_options = cls(
            auto_set_depth=auto_set_depth,
            pdf_filename=pdf_filename,
            pdf=pdf,
        )

        plot_sequence_options.additional_properties = d
        return plot_sequence_options

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
